{% extends "base.html" %}

{% block content %}
    <h1>Edit Client</h1>
    <form method="POST">
        {{ form.hidden_tag() }}
        <div class="form-group">
            {{ form.name.label(class="form-control-label") }}
            {{ form.name(class="form-control") }}
        </div>
        <div class="form-group">
            {{ form.date_of_birth.label(class="form-control-label") }}
            {{ form.date_of_birth(class="form-control") }}
        </div>
        <div class="form-group">
            {{ form.email.label(class="form-control-label") }}
            {{ form.email(class="form-control") }}
        </div>
        <div class="form-group">
            {{ form.phone_number.label(class="form-control-label") }}
            {{ form.phone_number(class="form-control") }}
        </div>
        <div class="form-group">
            {{ form.center_case_id.label(class="form-control-label") }}
            {{ form.center_case_id(class="form-control") }}
            <small class="form-text text-muted">Center Case ID must start with the consultant’s 5-letter prefix and be alphanumeric.</small>
        </div>
        <div class="form-group">
            {{ form.gender.label(class="form-control-label") }}
            {{ form.gender(class="form-control") }}
        </div>
        <div class="form-group">
            {{ form.referred_by.label(class="form-control-label") }}
            {{ form.referred_by(class="form-control") }}
        </div>
        <div class="form-group form-check">
            {{ form.is_active(class="form-check-input") }}
            {{ form.is_active.label(class="form-check-label") }}
        </div>
        <div class="form-group">
            {{ form.submit(class="btn btn-primary") }}
        </div>
    </form>
{% endblock %}
