"""CPM Assessment System - A complete assessment platform for Coloured Progressive Matrices tests."""

__version__ = "1.0.0"
__author__ = "Your Organization"
__email__ = "contact@yourorg.com"

# from .app import create_app

__all__ = ["__version__"]


