{% extends "base.html" %}

{% block content %}
<div class="content-section">
    <form method="POST">
        {{ form.hidden_tag() }}
        <fieldset class="form-group">
            <legend class="border-bottom mb-4">Reset Password</legend>
            <div class="form-group">
                {{ form.mobile_number.label(class="form-control-label") }}
                {% if form.mobile_number.errors %}
                    {{ form.mobile_number(class="form-control is-invalid") }}
                    <div class="invalid-feedback">
                        {% for error in form.mobile_number.errors %}
                            <span>{{ error }}</span>
                        {% endfor %}
                    </div>
                {% else %}
                    {{ form.mobile_number(class="form-control") }}
                {% endif %}
            </div>
        </fieldset>
        <div class="form-group">
            {{ form.submit(class="btn btn-outline-info") }}
        </div>
    </form>
</div>
<div class="border-top pt-3">
    <small class="text-muted">
        Remember your password? <a class="ml-2" href="{{ url_for('auth.login') }}">Sign In</a>
    </small>
</div>
{% endblock %}