<p>Dear {{ recipient_name }},</p>
<p>The assessment <strong>{{ assessment_name }}</strong> has been completed by <strong>{{ taker_name }}</strong>.</p>
<p>You can view the report by logging into the portal.</p>
<p>Completion Date: {{ completion_date }}</p>
<p>Thank you,</p>
<p>The Assessment Team</p>
