{% extends "base.html" %}

{% block content %}
    <h1>Change Password</h1>
    <form method="POST">
        {{ form.hidden_tag() }}
        <div class="form-group">
            {{ form.old_password.label(class="form-control-label") }}
            {{ form.old_password(class="form-control form-control-lg") }}
        </div>
        <div class="form-group">
            {{ form.new_password.label(class="form-control-label") }}
            {{ form.new_password(class="form-control form-control-lg") }}
        </div>
        <div class="form-group">
            {{ form.confirm_password.label(class="form-control-label") }}
            {{ form.confirm_password(class="form-control form-control-lg") }}
        </div>
        <div class="form-group">
            {{ form.submit(class="btn btn-outline-info") }}
        </div>
    </form>
{% endblock %}
