<div style="font-family: Arial, sans-serif; line-height: 1.6;">
  <h2 style="color:#333; margin-bottom:8px;">Password Changed</h2>
  <p style="margin:0 0 12px 0;">Hello {{ recipient_name }},</p>
  <p style="margin:0 0 12px 0;">
    The user <strong>{{ username }}</strong> ({{ email }}) has changed their account password.
  </p>
  {% if changed_at %}
  <p style="margin:0 0 12px 0;">
    Change time: {{ changed_at }}
  </p>
  {% endif %}
  <p style="margin:0 0 12px 0;">
    If this was not initiated by the user, please investigate immediately.
  </p>
  <hr style="border:none; border-top:1px solid #eee; margin:16px 0;">
  <p style="font-size:12px; color:#777; margin:0;">
    This is an automated notification from the Assessment Site.
  </p>
</div>
