{% extends "base.html" %}

{% block content %}
    <h1>Profile</h1>
    <p><strong>Username:</strong> {{ user.username }}</p>
    <p><strong>Email:</strong> {{ user.email }}</p>
    <p><strong>Role:</strong> {{ user.role }}</p>
    <a href="{{ url_for('profile.edit_profile') }}" class="btn btn-primary">Edit Profile</a>
    <a href="{{ url_for('profile.change_password') }}" class="btn btn-secondary">Change Password</a>
{% endblock %}
