<p>Dear {{ client.name }},</p>
<p>Your consultant has invited you to take the assessment: <strong>{{ assessment.name }}</strong>.</p>
<p>Description: {{ assessment.description }}</p>
<p>Please click on the link below to start your assessment:</p>
<p><a href="{{ assessment_link }}">{{ assessment_link }}</a></p>
<p>Thank you,</p>
<p>The Assessment Team</p>
