{% extends "base.html" %}

{% block title %}Confirm Assessment Start{% endblock %}

{% block content %}
<div class="container mt-5">
    <div class="row justify-content-center">
        <div class="col-md-8 text-center">
            <div class="card">
                <div class="card-header">
                    <h2>Confirm Your Assessment</h2>
                </div>
                <div class="card-body">
                    <p>You have been invited to take the following assessment:</p>
                    <h3 class="mb-4">{{ assessment.name }}</h3>
                    <p>
                        This is a one-time link. You can use this link to resume your assessment until you submit it.
                        After submission, the link cannot be used again.
                    </p>
                    <form method="POST" action="{{ url_for('main.start_invited_assessment', token=token) }}">
                        <button type="submit" class="btn btn-primary btn-lg">Start Assessment</button>
                    </form>
                </div>
                <div class="card-footer text-muted">
                    If you did not expect this invitation, you can safely close this page.
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}
