{% extends "base.html" %}

{% block content %}
    <h1>Client Assessment Report</h1>
    <div class="card">
        <div class="card-header">
            <h3>{{ client_assessment.assessment.name }}</h3>
        </div>
        <div class="card-body">
            <p><strong>Client:</strong> {{ client_assessment.client.name }} ({{ client_assessment.client.email }})</p>
            <p><strong>Completed Date:</strong> {{ client_assessment.completed_date.strftime('%Y-%m-%d %H:%M') }}</p>
            <p><strong>Score:</strong> {{ client_assessment.score }}</p>
            <p><strong>Feedback:</strong> {{ client_assessment.feedback }}</p>
        </div>
        <div class="card-footer">
            <a href="{{ url_for('admin.reports') }}" class="btn btn-primary">Back to Reports</a>
        </div>
    </div>
{% endblock %}
