<p>Dear {{ client.name }},</p>
<p>Your consultant has invited you to take the following assessments:</p>
<ul>
    {% for item in links %}
    <li>
        <strong>{{ item.assessment_name }}</strong><br>
        <a href="{{ item.link }}">{{ item.link }}</a>
    </li>
    {% endfor %}
</ul>
<p>Please complete them at your earliest convenience.</p>
<p>Thank you,</p>
<p>The VR Wellness Team</p>
