{% extends "base.html" %}

{% block title %}Link Expired{% endblock %}

{% block content %}
<div class="container mt-5">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card border-danger">
                <div class="card-header bg-danger text-white">
                    <h4 class="mb-0">
                        <i class="fas fa-clock"></i>
                        Link Expired
                    </h4>
                </div>
                <div class="card-body">
                    <div class="alert alert-danger" role="alert">
                        <h5 class="alert-heading">This link has expired</h5>
                        <p>For security reasons, this link was only valid for a limited time and has now expired.</p>
                        <hr>
                        <p class="mb-0">
                            {% if link_type == 'assessment' %}
                                If you need to take the assessment, please contact your administrator or consultant to request a new invitation link.
                            {% elif link_type == 'password_reset' %}
                                If you still need to reset your password, please <a href="{{ url_for('auth.reset_password_request') }}" class="alert-link">request a new password reset link</a>.
                            {% else %}
                                If you need access to this resource, please contact support for assistance.
                            {% endif %}
                        </p>
                    </div>
                    
                    <div class="mt-4">
                        <a href="{{ url_for('index') }}" class="btn btn-primary">
                            <i class="fas fa-home"></i>
                            Return to Home
                        </a>
                        {% if link_type == 'password_reset' %}
                            <a href="{{ url_for('auth.reset_password_request') }}" class="btn btn-outline-secondary ml-2">
                                <i class="fas fa-key"></i>
                                Request New Reset Link
                            </a>
                        {% endif %}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}